@@ -19,11 +19,11 @@ Lingua::Conjunction - Convert lists into simple linguistic conjunctions
 
 =head1 VERSION
 
-Version 2.6
+Version 2.7
 
 =cut
 
-our $VERSION = '2.6';
+our $VERSION = '2.7';
 
 =head1 SYNOPSIS
 
@@ -36,7 +36,7 @@ and an updated version will be released.
 
 # Format of %language is as follows:
 # Two-letter ISO language codes... see L<Locale::Language> from CPAN for more details.
-# sep = item  separator (usually a comma)
+# sep = item separator (usually a comma)
 # alt = alternate ("phrase") separator
 # pen = 1 = use penultimate separator/0 = don't use penultimate
 #	(i.e., "Jack, Jill and Spot" vs. "Jack, Jill, and Spot")
@@ -114,25 +114,22 @@ You can also set connectives individually:
 
 sub conjunction {
 	# TODO: see List::ToHumanString
-	my @list = grep defined && /\S/, @_;
+	my @list = grep { defined && /\S/ } @_;
+	my $list_count = scalar @list;
 
-	return if(scalar(@list) == 0);
-	return $list[0] if(scalar(@list) == 1);
-	return join(" $punct{$list_type} ", @list) if((scalar(@list) == 2) && !(grep /$punct{sep}/, @list));
+	return if $list_count == 0;
+	return $list[0] if $list_count == 1;
 
-	if($punct{pen}) {
-		return join "$punct{sep} ", @list[ 0 .. $#list - 1 ],
-		  "$punct{$list_type} $list[-1]",
-		  unless grep /$punct{sep}/, @list;
-		return join "$punct{alt} ", @list[ 0 .. $#list - 1 ],
-		  "$punct{$list_type} $list[-1]";
-	} else {
-		return join "$punct{sep} ", @list[ 0 .. $#list - 2 ],
-		  "$list[-2] $punct{$list_type} $list[-1]",
-		  unless grep /$punct{sep}/, @list;
-		return join "$punct{alt} ", @list[ 0 .. $#list - 2 ],
-		  "$list[-2] $punct{$list_type} $list[-1]";
+	# Use appropriate separator for 2-item lists without punctuation conflicts
+	return join(" $punct{$list_type} ", @list) if $list_count == 2 && !grep { /$punct{sep}/ } @list;
+
+	# Quote with \Q incase the separator has regex characters e.g. '.'
+	my $separator = (grep { /\Q$punct{sep}\E/ } @list) ? $punct{alt} : $punct{sep};
+
+	if($punct{pen}) {	# Use Oxford comma?
+		return join("$separator ", @list[0 .. $#list - 1], "$punct{$list_type} $list[-1]");
 	}
+	return join("$separator ", @list[0 .. $#list - 2], "$list[-2] $punct{$list_type} $list[-1]");
 }
 
 =head2 separator
@@ -148,7 +145,7 @@ Returns the previous value.
 sub separator {
 	my $rc = $punct{'sep'};
 
-	$punct{sep} = $_[1];
+	$punct{'sep'} = $_[1];
 	return $rc;
 }
 
@@ -265,20 +262,16 @@ sub lang {
 # https://www.gnu.org/software/gettext/manual/html_node/The-LANGUAGE-variable.html
 sub _get_language
 {
-	if($ENV{'LANGUAGE'}) {
-		foreach my $l(split/:/, $ENV{'LANGUAGE'}) {
-			if($language{$l}) {
-				return $l;
-			}
-		}
+	if($ENV{'LANGUAGE'} && ($ENV{'LANGUAGE'} =~ /^([a-z]{2})/i)) {
+		return lc($1);
 	}
+
 	foreach my $variable('LC_ALL', 'LC_MESSAGES', 'LANG') {
 		my $val = $ENV{$variable};
 		next unless(defined($val));
 
-		$val = substr($val, 0, 2);
-		if($language{$val}) {
-			return $val;
+		if($val =~ /^([a-z]{2})/i) {
+			return lc($1);
 		}
 	}
 	return 'en';
